__author__ = 'tusharmakkar08'

try:
    from urllib.parse import urlparse, urlencode
    from urllib.request import urlopen, Request, urlretrieve
    from urllib.error import HTTPError
except ImportError:
    from urlparse import urlparse
    from urllib import urlencode
    from urllib2 import urlopen, Request, HTTPError
    from urllib import urlretrieve

import re
import os

URL_REGEX = r'https?://(?:[a-zA-Z]|[0-9]|[$-_@.&+]|[!*\(\),]|(?:%[0-9a-fA-F][0-9a-fA-F]))+'
LINK_END = '.githubusercontent.com'
DEFAULT_DIRECTORY = os.path.join(os.getcwd(), "github_images")


def github_image_downloader(url, directory_to_download=None):
    """
    Downloads Github images in a particular directory
    :param url: Github username url eg: https://github.com/tusharmakkar08
    :param directory_to_download: Directory where files will be downloaded ,
    if this is none then files downloaded to default directory
    :return:
    """
    response = urlopen(url)
    html = response.read().decode('utf-8')
    image_links = {link for link in re.findall(URL_REGEX, html) if LINK_END in link}
    user_name = url.split(".com/")[1].strip("/")
    download_directory = os.path.join(DEFAULT_DIRECTORY, directory_to_download) if directory_to_download else \
        os.path.join(DEFAULT_DIRECTORY, user_name)
    if not os.path.exists(download_directory):
        os.makedirs(download_directory)
    for index, image_link in enumerate(image_links):
        download_location = os.path.join(download_directory, user_name + "_" + str(index) + ".jpg")
        urlretrieve(image_link, download_location)




__author__ = 'tusharmakkar08'

try:
    from urllib.parse import urlparse, urlencode
    from urllib.request import urlopen, Request, urlretrieve
    from urllib.error import HTTPError
except ImportError:
    from urlparse import urlparse
    from urllib import urlencode
    from urllib2 import urlopen, Request, HTTPError
    from urllib import urlretrieve

import json
import webbrowser
from bs4 import BeautifulSoup
import requests


def __get_profile_id_fbv1(username):
    """
    Input : Username
    Output : Profile Id 
    """
    url = "http://graph.facebook.com/" + username
    response = urlopen(url)
    data = json.loads(response.read())
    return data['id']


def __get_profile_id_fbv2(username):
    """
    Input : Username
    Output : Profile Id HTML 
    """
    request_data = requests.post("http://findmyfbid.com/", data={'url': username})
    return request_data.text


def __get_user_id(html_string):
    """
    Input : HTML String from POST
    Output : Profile Id  
    """
    return BeautifulSoup(html_string, "html.parser").code.string


def _open_image_page(profile_id):
    """
    Input : Profile Id 
    Output : Opens a new tab with graph search results
    """
    try:
        new_url = "https://www.facebook.com/search/" + profile_id + "/photos-of"
        webbrowser.open_new_tab(new_url)
        return 1
    except Exception as e:
        print(e)
        return -1


def _open_profile_pic(profile_id):
    """
    Input : Profile Id 
    Output : Opens a new tab with profile picture of the username
    """
    try:
        new_url = "https://graph.facebook.com/" + profile_id + "/picture?width=800"
        webbrowser.open_new_tab(new_url)
        return 1
    except Exception as e:
        print(e)
        return -1


def _open_public_images(username):
    """
    :param username: username of a given person
    :return:
    """
    try:
        new_url = "https://www.facebook.com/" + username + "/photos_all"
        webbrowser.open_new_tab(new_url)
        return 1
    except Exception as e:
        print(e)
        return -1


def _download_profile_pic(profile_id, file_name):
    """
    :param file_name: File name to store
    :return:
    """
    image_link = "https://graph.facebook.com/" + profile_id + "/picture?width=800"
    urlretrieve(image_link, file_name)


def facebook_image_search(username, user_id=None, directory_to_download=None):
    """
    :param username: Username of the person to search eg: tusharmakkar08
    :param user_id: User Id of the person (integral number) eg: 647452998
    :return:
    """
    try:
        if not user_id:
            user_html = __get_profile_id_fbv2(username)
            user_id = __get_user_id(user_html)
            _open_public_images(username)
        else:
            new_url = "https://www.facebook.com/profile.php?id="+user_id+"&sk=photos"
            webbrowser.open_new_tab(new_url)
        _open_image_page(user_id)
        _open_profile_pic(user_id)
        if not directory_to_download:
            if username:
                directory_to_download = username + ".jpg"
            else:
                directory_to_download = user_id + ".jpg"
        _download_profile_pic(user_id, directory_to_download)
        return 1
    except Exception as e:
        print(e)
        return -1



__author__ = 'tusharmakkar08'

try:
    from urllib.parse import urlparse, urlencode
    from urllib.request import urlopen, Request, urlretrieve, build_opener
    from urllib.error import HTTPError
except ImportError:
    from urlparse import urlparse
    from urllib import urlencode
    from urllib2 import urlopen, Request, HTTPError, build_opener
    from urllib import urlretrieve

import re
import uuid
import os

URL_REGEX = r'https?://(?:[a-zA-Z]|[0-9]|[$-_@.&+]|[!*\(\),]|(?:%[0-9a-fA-F][0-9a-fA-F]))+'
PIC_EXTENSION = '.jpg'
DEFAULT_DIRECTORY = os.path.join(os.getcwd(), "linkedin_images")


def linkedin_image_downloader(url, directory_to_download=None):
    """
    Downloads LinkedIn images in a particular directory
    :param url: LinkedIn username url eg: https://www.linkedin.com/in/tusharmakkar08
    :param directory_to_download: Directory where files will be downloaded ,
    if this is none then files downloaded to default directory
    :return:
    """
    urlopener = build_opener()
    # Linkedin doesn't allow direct html access.
    urlopener.addheaders = [('User-agent', 'Mozilla/5.0')]
    html = urlopener.open(url).read().decode('utf-8')
    image_links = {link for link in re.findall(URL_REGEX, html) if PIC_EXTENSION in link and "shrinknp_200_200" in link}
    download_directory = os.path.join(DEFAULT_DIRECTORY, directory_to_download) if directory_to_download else \
        os.path.join(DEFAULT_DIRECTORY, url.strip("/").split("/")[-1])
    if not os.path.exists(download_directory):
        os.makedirs(download_directory)
    for image_link in image_links:
        download_location = os.path.join(download_directory, str(uuid.uuid4()) + PIC_EXTENSION)
        urlretrieve(image_link, download_location)



__author__ = 'tusharmakkar08'

try:
    from urllib.parse import urlparse, urlencode
    from urllib.request import urlopen, Request, urlretrieve
    from urllib.error import HTTPError
except ImportError:
    from urlparse import urlparse
    from urllib import urlencode
    from urllib2 import urlopen, Request, HTTPError
    from urllib import urlretrieve

import re
import os

URL_REGEX = r'https?://(?:[a-zA-Z]|[0-9]|[$-_@.&+]|[!*\(\),]|(?:%[0-9a-fA-F][0-9a-fA-F]))+'
PIC_EXTENSION = '.jpg'
DEFAULT_DIRECTORY = os.path.join(os.getcwd(), "instagram_images")


def instagram_image_downloader(url, directory_to_download=None):
    """
    Downloads Instagram images in a particular directory
    :param url: Instagram username url eg: https://www.instagram.com/tusharmakkar08/
    :param directory_to_download: Directory where files will be downloaded ,
    if this is none then files downloaded to default directory
    :return:
    """
    response = urlopen(url)
    html = response.read().decode('utf8')
    image_links = {link for link in re.findall(URL_REGEX, html) if PIC_EXTENSION in link}
    unique_image_set = set()
    download_directory = os.path.join(DEFAULT_DIRECTORY, directory_to_download) if directory_to_download else \
        os.path.join(DEFAULT_DIRECTORY, url.split(".com/")[1].strip("/"))
    if not os.path.exists(download_directory):
        os.makedirs(download_directory)
    for image_link in image_links:
        image_id = image_link.split(PIC_EXTENSION)[0].split("/")[-1]
        if image_id not in unique_image_set:
            unique_image_set.add(image_id)
            download_location = os.path.join(download_directory, image_id + PIC_EXTENSION)
            urlretrieve(image_link, download_location)



__author__ = 'tusharmakkar08'

import argparse

from image_search.search_files.instagram_search import instagram_image_downloader
from image_search.search_files.fb_search import facebook_image_search
from image_search.search_files.github_search import github_image_downloader
from image_search.search_files.quora_search import quora_image_downloader
from image_search.search_files.linkedin_search import linkedin_image_downloader


def _get_parser():
    """
    Command line Parser for search
    :return:
    """
    parser = argparse.ArgumentParser(description='Tool for fetching photos from facebook')
    parser.add_argument('-fb', '--facebook', action='store_true',
                        help='Fetch Facebook Photos (Default)')
    parser.add_argument('-ig', '--instagram', action='store_true',
                        help='Fetch Instagram Photos')
    parser.add_argument('-qr', '--quora', action='store_true',
                        help='Fetch Instagram Photos')
    parser.add_argument('-ln', '--linkedin', action='store_true',
                        help='Fetch LinkedIn Profile Photo')
    parser.add_argument('-gb', '--github', action='store_true',
                        help='Fetch Github Profile Photo')
    parser.add_argument('-n', '--username', metavar='username', type=str,
                        help='Username to analyze (For Linkedin add everything after ".com" eg: in/tusharmakkar08)')
    parser.add_argument('-u', '--url', metavar='url', type=str,
                        help='Profile Url to analyze')
    parser.add_argument('-i', '--id', metavar='id', type=str,
                        help='Profile Id to analyze (only for facebook)')
    parser.add_argument('-d', '--directory', metavar='directory', type=str, default=None,
                        help='Directory to download photos')
    return parser


def command_line_runner():
    """
    Entry point for script; Modify to add another search script
    :return:
    """
    parser = _get_parser()
    args = vars(parser.parse_args())
    if args["instagram"] and (args['username'] or args['url']):
        instagram_url = args['url'] if args['url'] else "https://www.instagram.com/" + args['username']
        instagram_image_downloader(instagram_url, args['directory'])
    elif args["github"] and (args['username'] or args['url']):
        github_url = args['url'] if args['url'] else "https://github.com/" + args['username']
        github_image_downloader(github_url, args['directory'])
    elif args["quora"] and (args['username'] or args['url']):
        quora_url = args['url'] if args['url'] else "https://www.quora.com/profile/" + args['username']
        quora_image_downloader(quora_url, args['directory'])
    elif args["linkedin"] and (args['username'] or args['url']):
        linkedin_url = args['url'] if args['url'] else "https://www.linkedin.com/" + args['username']
        linkedin_image_downloader(linkedin_url, args['directory'])
    elif not (args['username'] or args['url'] or args['id']):
        parser.print_help()
    elif args['username']:
        facebook_image_search(args['username'], directory_to_download=args['directory'])
    elif args['url']:
        username = args['url'].split(".com/")[1].split("/")[0]
        if ".php" in username:
            user_id = username.split('=')[1]
            facebook_image_search("", user_id, directory_to_download=args['directory'])
        else:
            facebook_image_search(username, directory_to_download=args['directory'])
    elif args['id']:
        user_id = args['id']
        facebook_image_search("", user_id, directory_to_download=args['directory'])
    else:
        parser.print_help()
    return


if __name__ == '__main__':
    command_line_runner()



__author__ = 'tusharmakkar08'

from pip.req import parse_requirements
from setuptools import setup, find_packages

install_reqs = parse_requirements('requirements.txt', session=False)
install_requirement = [str(ir.req) for ir in install_reqs]

setup(
    # Application name:
    name="imagyy",

    # Version number:
    version="1.0.3",

    # Application author details:
    author="Tushar Makkar",
    author_email="tusharmakkar08@gmail.com",

    # Packages
    packages=['image_search', 'image_search.search_files'],

    package_data={'': ['*.md']},

    license='MIT',
    platforms=['any'],
    # Details
    url="https://github.com/tusharmakkar08/Imagyy/",

    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.1',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
    ],

    # license="LICENSE.txt",
    description="Fetches public photos of different social networking platforms",

    long_description=open("README.rst").read(),

    entry_points={
        'console_scripts': [
            'imagyy = image_search.main_search:command_line_runner',
        ]
    },

    # Dependent packages (distributions)
    install_requires=install_requirement,

)
